# HCMI OPTIM
This package contains a flexible implementation of simulated annealing. There are plans to add similar code for genetic algorithms. It's possible that particle swarm optimization may also be added in the future.